%define upstream_name bulk_extractor

# warning: exiv2 crashes
%bcond_with exiv2

Name:           bulk-extractor
Version:        2.1.1
Release:        %mkrel 2
Summary:        A forensic media scanning and analysis tool
License:        MIT and Public Domain
Group:          Security
URL:            https://forensics.wiki/bulk_extractor/
Source0:        https://github.com/simsong/%{upstream_name}/releases/download/v%{version}/%{upstream_name}-%{version}.tar.gz
Patch0:         bulk-extractor-fix-build-with-gcc15.patch
BuildRequires:  flex
BuildRequires:  pkgconfig(absl_any)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(gpg-error)
BuildRequires:  pkgconfig(libewf)
BuildRequires:  pkgconfig(libgcrypt)
BuildRequires:  pkgconfig(libpcap)
# enable once porting to pcre2
#BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(re2)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(tre)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(zlib)

# We need fiwalk which was added to sleuthkit in v4.1.0
Requires:       sleuthkit >= 4.1
Requires:       zlib

%description
bulk_extractor is a C++ program that scans a disk image, a file, or a
directory of files and extracts useful information without parsing the
file system or file system structures. The results are stored in feature files
that can be easily inspected, parsed, or processed with automated tools.
It also creates histograms of features that it finds, as features that are
more common tend to be more important.

%prep
%autosetup -p1 -n %{upstream_name}-%{version}

%build
%configure %{?with_exiv2:--enable-exiv2=true}
%make_build

%install
%make_install

%files
%license LICENSE.md
%doc ChangeLog README.md NEWS COPYING
%doc doc/*.{html,md,txt} doc/Diagnostic_Notes/*.{md,html}
%{_bindir}/bulk_extractor
%{_mandir}/man1/bulk_extractor.1*


%changelog
* Fri May 09 2025 ns80 <ns80> 2.1.1-2.mga10
+ Revision: 2182191
- try to fix building with GCC 15

* Sun Dec 08 2024 daviddavid <daviddavid> 2.1.1-1.mga10
+ Revision: 2122711
- new version: 2.1.1 (thanks to Aurelian R, mga#33835)

* Wed Oct 02 2024 barjac <barjac> 1.5.5-9.mga10
+ Revision: 2102644
- revert 2101427

* Fri Sep 27 2024 barjac <barjac> 2.1.1-0.4.mga10
+ Revision: 2101427
- new version 2.1.1
- major upgrade to 2.x.x series
- drop all old patches and add mk-tar script to create tarball with sub-modules
- overhaul build requires and fix files list

* Wed Mar 30 2022 umeabot <umeabot> 1.5.5-8.mga9
+ Revision: 1835650
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 1.5.5-7.mga9
+ Revision: 1747727
- rebuild for openssl 3.0.0

* Sat Oct 10 2020 barjac <barjac> 1.5.5-6.mga8
+ Revision: 1633109
- Update BR for java

* Wed Feb 12 2020 umeabot <umeabot> 1.5.5-5.mga8
+ Revision: 1510808
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Sat Sep 22 2018 umeabot <umeabot> 1.5.5-4.mga7
+ Revision: 1295744
- Mageia 7 Mass Rebuild

* Sun Oct 15 2017 cjw <cjw> 1.5.5-3.mga7
+ Revision: 1172099
- patch2: fix build with openssl 1.1
- fix some autotools related problems

* Sat Feb 13 2016 umeabot <umeabot> 1.5.5-2.mga6
+ Revision: 959636
- Mageia 6 Mass Rebuild

* Mon Sep 21 2015 barjac <barjac> 1.5.5-1.mga6
+ Revision: 882051
- new version 1.5.5

* Wed Oct 15 2014 umeabot <umeabot> 1.4.4-4.mga5
+ Revision: 742733
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.4.4-3.mga5
+ Revision: 725988
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.4.4-2.mga5
+ Revision: 678246
- Mageia 5 Mass Rebuild

* Mon Feb 17 2014 barjac <barjac> 1.4.4-1.mga5
+ Revision: 593987
- new version 1.4.4

* Fri Oct 18 2013 umeabot <umeabot> 1.3-3.mga4
+ Revision: 503174
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 1.3-2.mga3
+ Revision: 347222
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 26 2012 malo <malo> 1.3-1.mga3
+ Revision: 310498
- fix BuildRequires
- fix java dependency
- update to 1.3
- update RPM group

* Fri Dec 16 2011 barjac <barjac> 1.1.1-1.mga2
+ Revision: 182808
- imported package bulk-extractor


* Fri Dec 16 2011 Barry Jackson <zen25000[at]zen.co.uk> 1.1.1-1.mga2
- New package   